@@ -18,6 +18,7 @@
 # Boston, MA 02111-1307, USA.
 #
 
+import os
 from contextlib import contextmanager
 
 from . import ast
@@ -142,7 +143,9 @@ class CCodeGenerator(object):
         for header in self.include_first_src:
             self.out_c.write("""#include "%s"\n""" % header)
 
-        self.out_c.write("""#include "%s"\n\n""" % (self.out_h_filename, ))
+        src_dir = os.path.dirname(os.path.realpath(self.out_c.name))
+        header = os.path.relpath(self.out_h_filename, src_dir)
+        self.out_c.write("""#include "%s"\n\n""" % (header, ))
 
         for header in self.include_last_src:
             self.out_c.write("""#include "%s"\n""" % header)
