@@ -506,7 +506,7 @@ void gi_marshalling_tests_utf8_full_in (gchar *utf8);
 
 
 _GI_TEST_EXTERN
-void gi_marshalling_tests_utf8_none_out (gchar **utf8);
+void gi_marshalling_tests_utf8_none_out (const gchar **utf8);
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_utf8_full_out (gchar **utf8);
@@ -517,7 +517,7 @@ void gi_marshalling_tests_utf8_dangling_out (gchar **utf8);
 
 
 _GI_TEST_EXTERN
-void gi_marshalling_tests_utf8_none_inout (gchar **utf8);
+void gi_marshalling_tests_utf8_none_inout (const gchar **utf8);
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_utf8_full_inout (gchar **utf8);
@@ -781,7 +781,7 @@ void gi_marshalling_tests_array_in_nonzero_nonlen (gint first, const guint8 *cha
 
 
 _GI_TEST_EXTERN
-gchar **gi_marshalling_tests_array_zero_terminated_return (void);
+const gchar **gi_marshalling_tests_array_zero_terminated_return (void);
 
 _GI_TEST_EXTERN
 gchar **gi_marshalling_tests_array_zero_terminated_return_null (void);
@@ -798,11 +798,11 @@ void gi_marshalling_tests_array_zero_terminated_in (gchar **utf8s);
 
 
 _GI_TEST_EXTERN
-void gi_marshalling_tests_array_zero_terminated_out (gchar ***utf8s);
+void gi_marshalling_tests_array_zero_terminated_out (const gchar ***utf8s);
 
 
 _GI_TEST_EXTERN
-void gi_marshalling_tests_array_zero_terminated_inout (gchar ***utf8s);
+void gi_marshalling_tests_array_zero_terminated_inout (const gchar ***utf8s);
 
 
 _GI_TEST_EXTERN
@@ -834,6 +834,9 @@ GArray *gi_marshalling_tests_garray_utf8_container_return (void);
 _GI_TEST_EXTERN
 GArray *gi_marshalling_tests_garray_utf8_full_return (void);
 
+_GI_TEST_EXTERN
+GArray *gi_marshalling_tests_garray_boxed_struct_full_return (void);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_garray_int_none_in (GArray *array_);
@@ -884,6 +887,9 @@ GPtrArray *gi_marshalling_tests_gptrarray_utf8_container_return (void);
 _GI_TEST_EXTERN
 GPtrArray *gi_marshalling_tests_gptrarray_utf8_full_return (void);
 
+_GI_TEST_EXTERN
+GPtrArray *gi_marshalling_tests_gptrarray_boxed_struct_full_return (void);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gptrarray_utf8_none_in (GPtrArray *parray_);
@@ -1316,14 +1322,6 @@ _GI_TEST_EXTERN
 void gi_marshalling_tests_union_inv (GIMarshallingTestsUnion *union_);
 
 
-_GI_TEST_EXTERN
-void gi_marshalling_tests_union_out (GIMarshallingTestsUnion **union_);
-
-
-_GI_TEST_EXTERN
-void gi_marshalling_tests_union_inout (GIMarshallingTestsUnion **union_);
-
-
 _GI_TEST_EXTERN
 void gi_marshalling_tests_union_method (GIMarshallingTestsUnion *union_);
 
@@ -1970,8 +1968,12 @@ struct _GIMarshallingTestsPropertiesObject {
     gchar **some_strv;
     GIMarshallingTestsBoxedStruct* some_boxed_struct;
     GList* some_boxed_glist;
+    GValue *some_gvalue;
     GVariant *some_variant;
     GObject *some_object;
+    GIMarshallingTestsFlags some_flags;
+    GIMarshallingTestsGEnum some_enum;
+    GByteArray *some_byte_array;
 };
 
 struct _GIMarshallingTestsPropertiesObjectClass {
